@@ -15,7 +15,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Id: Glib.pm 1091 2009-02-13 14:53:55Z tsch $
+# $Id: Glib.pm 1044 2008-11-03 21:04:12Z tsch $
 #
 
 package Glib;
@@ -36,6 +36,9 @@ use constant {
 	G_PRIORITY_DEFAULT_IDLE =>  200,
 	G_PRIORITY_LOW	        =>  300,
 	G_PARAM_READWRITE       => [qw/readable writable/],
+
+	SOURCE_CONTINUE         => 1,
+	SOURCE_REMOVE           => !1,
 };
 
 # export nothing by default.
@@ -63,7 +66,7 @@ our %EXPORT_TAGS = (
 our @EXPORT_OK = map { @$_ } values %EXPORT_TAGS;
 $EXPORT_TAGS{all} = \@EXPORT_OK;
 
-our $VERSION = '1.201';
+our $VERSION = '1.210';
 
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
